@@ -1,11 +1,13 @@
-__version__ = '3.10.0'
+"""Semantic Release
+"""
+__version__ = '4.0.1'
 
 
 from .errors import (SemanticReleaseBaseError, ImproperConfigurationError,  # noqa
                      UnknownCommitMessageStyleError)  # noqa
 
 
-def setup_hook(argv):
+def setup_hook(argv: list):
     """
     A hook to be used in setup.py to enable `python setup.py publish`.
 
