@@ -1,9 +1,12 @@
+"""CLI
+"""
 import os
 import sys
 
 import click
 
 from semantic_release import ci_checks
+from semantic_release.errors import GitError, ImproperConfigurationError
 
 from .history import (evaluate_version_bump, get_current_version, get_new_version,
                       get_previous_version, set_new_version)
@@ -14,11 +17,12 @@ from .settings import config
 from .vcs_helpers import (checkout, commit_new_version, get_current_head_hash,
                           get_repository_owner_and_name, push_new_version, tag_new_version)
 
-_common_options = [
+COMMON_OPTIONS = [
     click.option('--major', 'force_level', flag_value='major', help='Force major version.'),
     click.option('--minor', 'force_level', flag_value='minor', help='Force minor version.'),
     click.option('--patch', 'force_level', flag_value='patch', help='Force patch version.'),
     click.option('--post', is_flag=True, help='Post changelog.'),
+    click.option('--retry', is_flag=True, help='Retry the same release, do not bump.'),
     click.option('--noop', is_flag=True,
                  help='No-operations mode, finds the new version number without changing it.')
 ]
@@ -26,9 +30,9 @@ _common_options = [
 
 def common_options(func):
     """
-    Decorator that adds all the options in _common_options
+    Decorator that adds all the options in COMMON_OPTIONS
     """
-    for option in reversed(_common_options):
+    for option in reversed(COMMON_OPTIONS):
         func = option(func)
     return func
 
@@ -36,15 +40,19 @@ def common_options(func):
 def version(**kwargs):
     """
     Detects the new version according to git log and semver. Writes the new version
-    number and commits it(unless the noop-option is True.
+    number and commits it, unless the noop-option is True.
     """
-    click.echo('Creating new version..')
+    retry = kwargs.get("retry")
+    if retry:
+        click.echo('Retrying publication of the same version...')
+    else:
+        click.echo('Creating new version..')
     current_version = get_current_version()
     click.echo('Current version: {0}'.format(current_version))
     level_bump = evaluate_version_bump(current_version, kwargs['force_level'])
     new_version = get_new_version(current_version, level_bump)
 
-    if new_version == current_version:
+    if new_version == current_version and not retry:
         click.echo(click.style('No release will be made.', fg='yellow'))
         return False
 
@@ -64,6 +72,10 @@ def version(**kwargs):
             return False
         click.echo(click.style('The build was a success, continuing the release', 'green'))
 
+    if retry:
+        # No need to make changes to the repo, we're just retrying.
+        return True
+
     if config.get('semantic_release', 'version_source') == 'commit':
         set_new_version(new_version)
         commit_new_version(new_version)
@@ -75,10 +87,18 @@ def version(**kwargs):
 def changelog(**kwargs):
     """
     Generates the changelog since the last release.
+    :raises ImproperConfigurationError: if there is no current version
     """
     current_version = get_current_version()
-    log = generate_changelog(
-        get_previous_version(current_version), current_version)
+    if current_version is None:
+        raise ImproperConfigurationError(
+            "Unable to get the current version. "
+            "Make sure semantic_release.version_variable "
+            "is setup correctly"
+        )
+    previous_version = get_previous_version(current_version)
+
+    log = generate_changelog(previous_version, current_version)
     for section in CHANGELOG_SECTIONS:
         if not log[section]:
             continue
@@ -86,7 +106,7 @@ def changelog(**kwargs):
         click.echo(section.capitalize())
         click.echo(''.join(['-' for i in range(len(section))]))
         for item in log[section]:
-            click.echo(' - {0}'.format(item))
+            click.echo(' - {0} ({1})'.format(item[1], item[0]))
         click.echo('\n')
 
     if not kwargs.get('noop') and kwargs.get('post'):
@@ -110,8 +130,15 @@ def publish(**kwargs):
     """
     current_version = get_current_version()
     click.echo('Current version: {0}'.format(current_version))
-    level_bump = evaluate_version_bump(current_version, kwargs['force_level'])
-    new_version = get_new_version(current_version, level_bump)
+    retry = kwargs.get("retry")
+    if retry:
+        # The "new" version will actually be the current version, and the
+        # "current" version will be the previous version.
+        new_version = current_version
+        current_version = get_previous_version(current_version)
+    else:
+        level_bump = evaluate_version_bump(current_version, kwargs['force_level'])
+        new_version = get_new_version(current_version, level_bump)
     owner, name = get_repository_owner_and_name()
 
     ci_checks.check('master')
@@ -128,17 +155,23 @@ def publish(**kwargs):
             upload_to_pypi(
                 username=os.environ.get('PYPI_USERNAME'),
                 password=os.environ.get('PYPI_PASSWORD'),
+                # We are retrying, so we don't want errors for files that are already on PyPI.
+                skip_existing=retry,
             )
 
         if check_token():
             click.echo('Updating changelog')
-            log = generate_changelog(current_version, new_version)
-            post_changelog(
-                owner,
-                name,
-                new_version,
-                markdown_changelog(new_version, log, header=False)
-            )
+            try:
+                log = generate_changelog(current_version, new_version)
+                post_changelog(
+                    owner,
+                    name,
+                    new_version,
+                    markdown_changelog(new_version, log, header=False)
+                )
+            except GitError:
+                click.echo(click.style('Posting changelog failed.', 'red'), err=True)
+
         else:
             click.echo(
                 click.style('Missing token: cannot post changelog', 'red'), err=True)
@@ -148,12 +181,23 @@ def publish(**kwargs):
         click.echo('Version failed, no release will be published.', err=True)
 
 
+def filter_output_for_secrets(message):
+    output = message
+    username = os.environ.get('PYPI_USERNAME')
+    password = os.environ.get('PYPI_PASSWORD')
+    if username != '' and username is not None:
+        output = output.replace(username, '$PYPI_USERNAME')
+    if password != '' and password is not None:
+        output = output.replace(password, '$PYPI_PASSWORD')
+    return output
+
 #
 # Making the CLI commands.
 # We have a level of indirection to the logical commands
 # so we can successfully mock them during testing
 #
 
+
 @click.group()
 @common_options
 def main(**kwargs):
@@ -163,19 +207,31 @@ def main(**kwargs):
 @main.command(name='publish', help=publish.__doc__)
 @common_options
 def cmd_publish(**kwargs):
-    return publish(**kwargs)
+    try:
+        return publish(**kwargs)
+    except Exception as error:
+        click.echo(click.style(filter_output_for_secrets(str(error)), 'red'), err=True)
+        exit(1)
 
 
 @main.command(name='changelog', help=changelog.__doc__)
 @common_options
 def cmd_changelog(**kwargs):
-    return changelog(**kwargs)
+    try:
+        return changelog(**kwargs)
+    except Exception as error:
+        click.echo(click.style(filter_output_for_secrets(str(error)), 'red'), err=True)
+        exit(1)
 
 
 @main.command(name='version', help=version.__doc__)
 @common_options
 def cmd_version(**kwargs):
-    return version(**kwargs)
+    try:
+        return version(**kwargs)
+    except Exception as error:
+        click.echo(click.style(filter_output_for_secrets(str(error)), 'red'), err=True)
+        exit(1)
 
 
 if __name__ == '__main__':
@@ -186,5 +242,5 @@ if __name__ == '__main__':
     # This will have to be removed if there are ever global options
     # that are not valid for a subcommand.
     #
-    args = sorted(sys.argv[1:], key=lambda x: 1 if x.startswith('--') else -1)
-    main(args=args)
+    ARGS = sorted(sys.argv[1:], key=lambda x: 1 if x.startswith('--') else -1)
+    main(args=ARGS)
